const application = require("application");

const fs = require("file-system");
const Loki = require ('lokijs');
//const LokiNativeScriptAdapter = require("lokijs/src/loki-nativescript-adapter");
const LokiNativeScriptAdapter = require("loki-nativescript-adapter");

const config = require("./shared/config");

const colls =  {"artists": { unique: ['artistId']}, "albums": { unique: ['albumId']}, "tracks": {unique: ['trackId']}, "config": { unique: ['confKey','appVersion']}};

const path = fs.path.join(fs.knownFolders.documents().path, "lms.json");
console.log("global DB path:"+path);

const lokiNativeScriptAdapter = new LokiNativeScriptAdapter();
const partitioningAdapter = new Loki.LokiPartitioningAdapter( lokiNativeScriptAdapter, { paging: true, pageSize:5*1024*1024, delimiter: '$<-|->$'});
//const partitioningAdapter = new Loki.LokiPartitioningAdapter( lokiNativeScriptAdapter, { paging: true, pageSize:5*1024*1024});

global.ldb = new Loki(path, {
	adapter: partitioningAdapter,
//	adapter: lokiNativeScriptAdapter,
//	destructureDelimiter: '§<\n',
	env: "NATIVESCRIPT",
	throttledSaves: true,
	verbose: true
});

/*
global.ldb = new Loki(path, {
	adapter: new LokiNativeScriptAdapter(),
	verbose: true
});
*/

application.on(application.exitEvent, function (args) {
	console.log("app exit");

	var c = global.ldb.getCollection( "config");
	if( c.by("confKey",1)) {
		c.update( config.settings);
	} else {
		c.insert( config.settings);
	}
	//global.ldb.removeCollection( "config");

	/*
	for (const cname of Object.keys(colls)) {
		global.ldb.removeCollection( cname);
	}
	*/

	global.ldb.saveDatabase( function( err) {
		console.log("db save");
		if( err) {
			console.dump( err);
		}
		global.ldb.close( function( err) {
			console.log("db close");
			if( err) {
				console.dump( err);
			}
		});
	});
});


// TEST
application.on(application.suspendEvent, function (args) {
    if (args.android) {
        // For Android applications, args.android is an android activity class.
        console.log("suspendEvent Activity: " + args.android);
    } else if (args.ios) {
        // For iOS applications, args.ios is UIApplication.
        console.log("UIApplication: " + args.ios);
    }
});

application.on(application.resumeEvent, function (args) {
    if (args.android) {
        // For Android applications, args.android is an android activity class.
        console.log("resumeEvent Activity: " + args.android);
    } else if (args.ios) {
        // For iOS applications, args.ios is UIApplication.
        console.log("UIApplication: " + args.ios);
    }
});

// ------------------

global.ldb.loadDatabase({}, function() {
	console.log("DB loaded");

	var c;

	for (const cname of Object.keys(colls)) {
		c = global.ldb.getCollection( cname);
		if ( !c) {
			c = global.ldb.addCollection( cname, colls[cname]);
			console.log("creating collection "+cname);
		}
	}

	var cnf = global.ldb.getCollection( "config").by("confKey",1);
	if( cnf) {
		Object.assign( config.settings, cnf);
		console.dump( config.settings);
	}

	application.cssFile = "app-"+config.settings.appTheme+".css";
	application.start({ moduleName: "main-page" });
});

/*
application.on(application.launchEvent, function (args) {
	console.log("app start");
});
*/

